<?php

namespace Litecms\GoogleCaptcha\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\GoogleCaptcha\Models\CaptchaSetting;

class CaptchaSettingPolicy
{

    /**
     * Determine if the given user can view the captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, CaptchaSetting $captcha_setting)
    {
        if ($user->canDo('google_captcha.captcha_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $captcha_setting->user_id == user_id() && $captcha_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('google_captcha.captcha_setting.create');
    }

    /**
     * Determine if the given user can update the given captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, CaptchaSetting $captcha_setting)
    {
        if ($user->canDo('google_captcha.captcha_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $captcha_setting->user_id == user_id() && $captcha_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CaptchaSetting $captcha_setting)
    {
        return $captcha_setting->user_id == user_id() && $captcha_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CaptchaSetting $captcha_setting)
    {
        if ($user->canDo('google_captcha.captcha_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given captcha_setting.
     *
     * @param UserPolicy $user
     * @param CaptchaSetting $captcha_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CaptchaSetting $captcha_setting)
    {
        if ($user->canDo('google_captcha.captcha_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
