<?php

namespace Litecms\GoogleCaptcha\Providers;

use Illuminate\Support\ServiceProvider;

class GoogleCaptchaServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'google_captcha');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'google_captcha');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.google_captcha', function ($app) {
            return $this->app->make('Litecms\GoogleCaptcha\GoogleCaptcha');
        });

                // Bind CaptchaSetting to repository
        $this->app->bind(
            'Litecms\GoogleCaptcha\Interfaces\CaptchaSettingRepositoryInterface',
            \Litecms\GoogleCaptcha\Repositories\Eloquent\CaptchaSettingRepository::class
        );

        $this->app->register(\Litecms\GoogleCaptcha\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\GoogleCaptcha\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\GoogleCaptcha\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.google_captcha'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/google_captcha.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/google_captcha')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/google_captcha')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
